
# Vitesse maxi en al/an --> en fraction de c
Vmax = (4500.0 * 3600.0*24.0*365.0) / 9.46e12

# Distance en al
D = 10.5
# Distance d'acclration
Da = 3
# Distance de vol libre
Dl = D - 2.0 * Da

# Dure de l'acclration
Ta = 2.0 * Da / Vmax
# Dure du vol libre
Tl = Dl / Vmax
# Dure totale du voyage
T = 2.0 * Ta + Tl

# Acclration
a = Vmax / Ta

# Choix des relais
#  t0 = depart du rservoir
#  tau = point de rencontre
#t0_1 = 70
tau_1 = Ta/2
aR_1 = 2*a
#t0_2 = -400
tau_2 = Ta
aR_2 = 2*a
#t0_3 = -400
tau_3 = T-Ta/2
aR_3 = 2*a

# Phase d'acclration
Aa(t) = 0.5*a*t**2
Va(t) = a*t
# Vol libre
Al(t) = Vmax*(t-Ta) + Aa(Ta)
Vl(t) = Vmax
# Phase de freinage
Af(t) = -0.5*a*(t-T)**2 + D
Vf(t) = -a*(t-T)
# Trajectoire complte
A(t) = (t<0)?1/0 : (t<Ta)?Aa(t):((t<(T-Ta))?Al(t):Af(t))
V(t) = (t<0)?1/0 : (t<Ta)?Va(t):((t<(T-Ta))?Vl(t):Vf(t))

# Trajectoire d'un rservoir
#  t0 est la date de dpart
#  tau est la date de rencontre avec l'arche
#  theta est la date o le reservoir atteint la vitesse souhaite
#    ( = vitesse de l'arche au point de rencontre ---> fin de l'acclration)

# Pour une acclration donne
t0(aR,tau) = (tau<T-Ta)? ( \
    0.5*tau*(1-a/aR)  \
  ):( \
    0.5*(2*D/a/(tau-T)+tau+T + a/aR*(tau-T))  \
  )
 
t0_1 = t0(aR_1,tau_1)
t0_2 = t0(aR_2,tau_2)
t0_3 = t0(aR_3,tau_3)
 
# Pour une date de dpart donne
theta(t0,tau) = (tau<T-Ta)? ( \
    tau-t0		      \
  ):(			      \
    2*D/a/(tau-T)+tau+T-t0    \
  )

theta_1 = theta(t0_1,tau_1)
theta_2 = theta(t0_2,tau_2)
theta_3 = theta(t0_3,tau_3)

# Trajectoire
R(t,t0,tau) = (t<t0||t>theta(t0,tau))? 1/0 :	  \
  (tau<T-Ta)? (							    \
    (t<=tau-t0)? 0.5* a*   tau /(theta(t0,tau)-t0) *(t-t0)**2 : 1/0 \
  ):(								    \
    (t<=tau-t0)? 0.5* a*(T-tau)/(theta(t0,tau)-t0) *(t-t0)**2 : 1/0 \
  )

########### Prsentation des tracs

# Sparations des diffrentes phases
set x2tics ( "Ta" Ta, "T-Ta" T-Ta )
set y2tics ( "Da" Da, "D-Da" D-Da )
set xtics nomirror
set ytics nomirror
set grid noxtics noytics x2tics y2tics

# Bornes du trac
tmin = t0_3-(T-t0_3)*0.03 # un peu avant le dpart du rservoir 1
tmax = T
dmin = 0
dmax = D

# repres des points de rencontre
set style arrow 22 nohead lt rgbcolor"#B0B050"
set arrow 121 from t0_1,0 to t0_1,A(tau_1) as 22
set arrow 122 from t0_1,A(tau_1) to tau_1,A(tau_1) as 22
set arrow 123 from tau_1,A(tau_1) to tau_1,0 as 22
set style arrow 21 nohead lt rgbcolor"#B050B0"
set arrow 111 from t0_2,0 to t0_2,A(tau_2) as 21
set arrow 112 from t0_2,A(tau_2) to tau_2,A(tau_2) as 21
set arrow 113 from tau_2,A(tau_2) to tau_2,0 as 21
set style arrow 20 nohead lt rgbcolor"#50B0B0"
set arrow 101 from t0_3,0 to t0_3,A(tau_3) as 20
set arrow 102 from t0_3,A(tau_3) to tau_3,A(tau_3) as 20
set arrow 103 from tau_3,A(tau_3) to tau_3,0 as 20

# tangentes aux points de rencontre
set arrow 210 from (theta_1+t0_1)/2,0 to tau_1,A(tau_1) as 22
set arrow 220 from (theta_2+t0_2)/2,0 to tau_2,A(tau_2) as 21
set arrow 230 from (theta_3+t0_3)/2,0 to tau_3,A(tau_3) as 20

set samples 100
set yzeroaxis lt -1
set grid front

set multiplot

unset key

# Zone des trajectoires du rservoir 3 et tangente associe (en arrire plan!)
plot [t=tmin:tmax] [dmin:dmax] \
  R(t,theta_3+t0_3-tau_3,tau_3) notitle with filledcurves x1 lt rgbcolor "#DDFFFF", \
  (t-(theta_3+t0_3)/2)*A(tau_3)/(tau_3-(theta_3+t0_3)/2) with filledcurves x1 lt rgbcolor "#FFFFFF"

# repres des theta 2 et 3
set object 120 rectangle from t0_1,0 to theta_1,R(theta_1,t0_1,tau_1) \
  behind fc rgbcolor "#FFFFBB"
set object 110 rectangle from t0_2,0 to theta_2,R(theta_2,t0_2,tau_2) \
  behind fc rgbcolor "#FFBBFF"

# Zone des trajectoires des rservoirs 1 et 2 et tangentes associes 
plot [t=tmin:tmax] [dmin:dmax] \
  R(t,0   ,tau_1) notitle with filledcurves x1 lt rgbcolor "#FFFFDD",	\
  (t-(theta_1+t0_1)/2)*A(tau_1)/(tau_1-(theta_1+t0_1)/2) with filledcurves x1 lt rgbcolor "#FFFFFF", \
\
  R(t,0   ,tau_2) notitle with filledcurves x1 lt rgbcolor "#FFDDFF",	\
  (t-(theta_2+t0_2)/2)*A(tau_2)/(tau_2-(theta_2+t0_2)/2) with filledcurves x1 lt rgbcolor "#FFFFFF"

# Dfinition du cadre de la lgende
set key at first t0_3+(T-t0_3)*0.03, first (D-Da)*0.97 left top \
  reverse Left box height 1

set grid back

# repres de theta 1
set object 100 rectangle from t0_3,0 to theta_3,R(theta_3,t0_3,tau_3) \
  behind fc rgbcolor "#BBFFFF"
# On de redessine pas les 2 et 3
unset object 110
unset object 120

# Trajectoires et trajectoires extrmes
plot [t=tmin:tmax] [dmin:dmax] \
  A(t) title "Arche" with lines lw 2 lt 1, \
  R(t,t0_1,tau_1) title "Rservoir 1" with lines lt rgbcolor "#808010",	\
  R(t,0   ,tau_1) notitle with lines lt rgbcolor"#DDDD66", \
  R(t,t0_2,tau_2) title "Rservoir 2" with lines lt rgbcolor "#801080",	\
  R(t,0   ,tau_2) notitle with lines lt rgbcolor"#DD66DD", \
  R(t,t0_3,tau_3) title "Rservoir 3" with lines lt rgbcolor "#108080", \
  R(t,theta_3+t0_3-tau_3,tau_3) notitle with lines lt rgbcolor"#66DDDD"

unset multiplot

unset arrow
unset object
